==> danila-lib-2.2.2.tar.gz: danila-lib-2.2.2/data/neuro/models.py <==
RAMA_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/4xtNt0zftHFFVg'
RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/sE5iSXYWL3xEkQ'
RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/zAEw0_ALgtBg9Q'
RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/rgthm-mMrbhOmw'
RAMA_BEJICKAYA_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/QhicLdm2-PT6oA'
# TEXT_RECOGNIZE_RUZHIMMASH_MODEL_ADDRESS = 'https://disk.yandex.ru/d/C2hDMsbTZMnL8Q' -7500_b7500_r
# TEXT_RECOGNIZE_BEGICKAYA_MODEL_ADDRESS = 'https://disk.yandex.ru/d/C2hDMsbTZMnL8Q'
TEXT_RECOGNIZE_RUZHIMMASH_MODEL_ADDRESS = 'https://disk.yandex.ru/d/GcI-mAtwpb2I-g' # 11000_b_11000_r
TEXT_RECOGNIZE_BEGICKAYA_MODEL_ADDRESS = 'https://disk.yandex.ru/d/GcI-mAtwpb2I-g'  # 11000_b_11000_r

RAMA_PROD_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/8FI8TaTwaCfbSA'
VAGON_NUMBER_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/ZGS0sdk1syJmcQ'
VAGON_NUMBER_DETECT_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/3artWauJULaWXw'
DETAIL_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/Xamk_OYzYAbGhg'
DETAIL_CLASSIFY_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/dcd01St30wL2zQ'

VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS = 'https://disk.yandex.ru/d/eh714_PrjFyLHg'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/iZxGW6ZaXZDoQQ'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_3 = 'https://disk.yandex.ru/d/wd697DtHumhsjA'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_4 = 'https://disk.yandex.ru/d/4UqcWigCF5hCqw'

==> danila-lib-2.2.6.tar.gz: danila-lib-2.2.6/data/neuro/models.py <==
RAMA_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/4xtNt0zftHFFVg'
RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/sE5iSXYWL3xEkQ'
RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/zAEw0_ALgtBg9Q'
RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/rgthm-mMrbhOmw'
RAMA_BEJICKAYA_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/QhicLdm2-PT6oA'
# TEXT_RECOGNIZE_RUZHIMMASH_MODEL_ADDRESS = 'https://disk.yandex.ru/d/C2hDMsbTZMnL8Q' -7500_b7500_r
# TEXT_RECOGNIZE_BEGICKAYA_MODEL_ADDRESS = 'https://disk.yandex.ru/d/C2hDMsbTZMnL8Q'
TEXT_RECOGNIZE_RUZHIMMASH_MODEL_ADDRESS = 'https://disk.yandex.ru/d/GcI-mAtwpb2I-g' # 11000_b_11000_r
TEXT_RECOGNIZE_BEGICKAYA_MODEL_ADDRESS = 'https://disk.yandex.ru/d/GcI-mAtwpb2I-g'  # 11000_b_11000_r

RAMA_PROD_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/8FI8TaTwaCfbSA'
RAMA_PROD_CLASSIFY_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/P7rKubXWHJjgCQ'
VAGON_NUMBER_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/ZGS0sdk1syJmcQ'
VAGON_NUMBER_DETECT_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/3artWauJULaWXw'
DETAIL_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/Xamk_OYzYAbGhg'
DETAIL_CLASSIFY_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/_t4r3N7a2Uy3cA'

VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS = 'https://disk.yandex.ru/d/eh714_PrjFyLHg'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/iZxGW6ZaXZDoQQ'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_3 = 'https://disk.yandex.ru/d/wd697DtHumhsjA'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_4 = 'https://disk.yandex.ru/d/4UqcWigCF5hCqw'
